<?php

if ( $with_priority ) {

	wpj_display_password_field();

} else {

	wpj_display_phone_number_field();

	wpj_display_company_field();

	wpj_display_recaptcha_field( 'default_register' );

	wpj_display_tos_field();

	if (
		( wpj_get_option( 'wpjobster_register_page_id' ) && wpj_page_content_type( wpj_get_option( 'wpjobster_register_page_id' ) ) != 'page_builder' )
		|| ( $GLOBALS['pagenow'] === 'wp-login.php' && empty( $_POST['provider'] ) )
	) { ?>

		<div class="register-outer-wrapper">

			<?php wpj_display_or_field();

			do_action( 'wordpress_social_login' );

			wpj_display_already_field( 'register' ); ?>

		</div>

	<?php }

}